#!/bin/bash -uex
# Deploy Jenkins Master and Slave Charm Applications for OpenStack Charm CI

DEPLOY_SCRATCH_DIR="$HOME/deploy2"
#JM_CHARM="cs:xenial/jenkins-4"
#JM_CHARM="cs:xenial/jenkins-2"   # Upstream before storage support
#JM_CHARM="cs:~1chb1n/jenkins"    # WIP based on upstream
#JS_CHARM="cs:~free.ekanayaka/xenial/jenkins-slave-2"    # Already has jenkins-slave deb packed in files dir
JM_CHARM="lp:~1chb1n/+junk/jenkins-reactive-temp-build"
JS_CHARM="lp:~1chb1n/+junk/jenkins-slave-legacy-mash"
JM_PKG_URL="https://pkg.jenkins.io/debian-stable/binary/jenkins_2.7.4_all.deb"
JM_PKG_FILENAME="$(echo "${JM_PKG_URL##*/}")"
SERIES="xenial"

# Fetch and "Fat-pack" the charms
mkdir -vp $DEPLOY_SCRATCH_DIR
stat $DEPLOY_SCRATCH_DIR/charm-jenkins ||\
    bzr branch $JM_CHARM $DEPLOY_SCRATCH_DIR/charm-jenkins
    #charm pull $JM_CHARM $DEPLOY_SCRATCH_DIR/charm-jenkins

stat $DEPLOY_SCRATCH_DIR/charm-jenkins-slave ||\
    bzr branch $JS_CHARM $DEPLOY_SCRATCH_DIR/charm-jenkins-slave
    #charm pull $JS_CHARM $DEPLOY_SCRATCH_DIR/charm-jenkins-slave

if ! stat $DEPLOY_SCRATCH_DIR/$JM_PKG_FILENAME; then
    . ~/proxy_set.sh
    env | egrep "prox|PROX"
    wget -v $JM_PKG_URL -P $DEPLOY_SCRATCH_DIR --show-progress
    . ~/proxy_unset.sh
fi

rm -fv $DEPLOY_SCRATCH_DIR/charm-jenkins/files/*jenkins*deb ||:
mkdir -vp $DEPLOY_SCRATCH_DIR/charm-jenkins/files/
cp -fv $DEPLOY_SCRATCH_DIR/$JM_PKG_FILENAME $DEPLOY_SCRATCH_DIR/charm-jenkins/files/
(cd $DEPLOY_SCRATCH_DIR/charm-jenkins/files/
    ln -s $JM_PKG_FILENAME jenkins.deb)

juju switch osci-serverstack:osci

juju status osci-master | grep "^osci-master " ||
    juju deploy  $DEPLOY_SCRATCH_DIR/charm-jenkins        osci-master  -n 1  --constraints="mem=7G  cores=4 root-disk=100G"  --config config/juju-apps/osci-master.yaml  --series $SERIES

juju status osci-task | grep "^osci-task" ||
    juju deploy  $DEPLOY_SCRATCH_DIR/charm-jenkins-slave  osci-task   -n 2   --constraints="mem=12G cores=8 root-disk=80G"   --config config/juju-apps/osci-task.yaml    --series $SERIES

juju status osci-slave | grep "^osci-slave " ||
    juju deploy  $DEPLOY_SCRATCH_DIR/charm-jenkins-slave  osci-slave  -n 12  --constraints="mem=3G  cores=4 root-disk=40G"   --config config/juju-apps/osci-slave.yaml   --series $SERIES

juju status osci-lab | grep "^osci-lab " ||
    juju deploy  $DEPLOY_SCRATCH_DIR/charm-jenkins-slave  osci-lab    -n 4   --constraints="mem=3G  cores=4 root-disk=40G"   --config config/juju-apps/osci-lab.yaml     --series $SERIES

# Temp hack. Should juju-wait instead. And the charms shouldn't not-work if relating too soon!
#sleep 600

juju add-relation   osci-master:master   osci-task:slave ||:
juju add-relation   osci-master:master   osci-slave:slave ||:
juju add-relation   osci-master:master   osci-lab:slave ||:

UNIT_IMPORT_IDS="1chb1n james-page thedac admcleod"
juju switch controller
juju run --all "sudo su - ubuntu -c \"ssh-import-id $UNIT_IMPORT_IDS\""
juju switch osci
juju run --all "sudo su - ubuntu -c \"ssh-import-id $UNIT_IMPORT_IDS\""
juju run --all "sudo su - jenkins -c \"ssh-import-id $UNIT_IMPORT_IDS\""

# /!\ The upstream charm relies on failed hook re-execution.  It will
# be necessary to retry the master after it fails once, like so:
#juju resolved osci-master/0
