#!/bin/bash -ex
echo $0

# Copy ssh key files and init bzr lp-login on master and all slaves,
# verify bzr checkout capability as the jenkins user.
# FYI nfs checkout is unrelated and arbitrary, chosen for small size ~100k.

. config/env-common

f_dst="${JENKINS_HOME}/.ssh"
f_tmp="${U_HOME}/.ssh"
f_src="${PUB_KEY} ${PRIV_KEY} ${SSH_CONF}"
base_src="assets"
hostkeys=$(cat ${base_src}/*_host_keys)
d_str=$(date +'%H%M%S')

for srcs in $f_src; do
    if [ ! -f "${base_src}/${srcs}" ]; then
        echo "Local source file ${srcs} not found."
        pwd
        exit 1
    fi
done

for unit in $UNITS; do
    echo "Copying SSH key files to ${unit}..."
    juju ssh ${unit} "sudo mkdir -vp ${f_dst} && sudo mkdir -p ${f_tmp} &&\
        sudo echo '${hostkeys}' > /tmp/hk${d_str} &&\
        sudo cp -fv /tmp/hk${d_str} /root/.ssh/known_hosts &&\
        sudo mv -fv /tmp/hk${d_str} ${f_dst}/known_hosts"

    for srcs in $f_src; do
        echo "    $srcs --> ${unit}:${f_tmp}"
        juju scp ${base_src}/${srcs} ${unit}:${f_tmp}
        juju ssh ${unit} "sudo cp -fv ${f_tmp}/${srcs} ${f_dst}"
    done

    juju ssh ${unit} "sudo chown -R jenkins:nogroup ${f_dst} &&\
        sudo chown -R ubuntu:nogroup ${f_tmp} &&\
        sudo chown -R jenkins:jenkins ${f_dst} &&\
        sudo chmod 0600 ${f_dst}/known_hosts &&\
        sudo su - jenkins -c 'bzr whoami \"${BZR_WHOAMI}\"' &&\
        sudo su - jenkins -c 'bzr launchpad-login $LP_ID' &&\
        sudo su - jenkins -c 'bzr co --lightweight lp:charms/nfs /tmp/nfs${d_str}'"
done
