#!/bin/bash -e
echo $0

# Set up juju environment and novarc on master and all slaves

. $(dirname $0)/../../env-common

# ---------------------------------------------
# DEPRECATED:  this is now handled by deploy.py
# ---------------------------------------------

juju_env_base="osci"
juju_dir="${JENKINS_HOME}/.juju"
env_templ="deploy-files/environments.yaml"

# Install tools locally if not already installed
dpkg -l uuid pwgen >> /dev/null 2>&1 || sudo apt-get install uuid pwgen

# Get values from the first local juju environment
apt_proxy=$(grep 'apt-http-proxy' ~/.juju/environments.yaml | head -n 1 | awk '{ print $2 }')

# Set up juju environments and novarc
[[ -d "out" ]] || mkdir out
all_juju_envs="out/environments_all.yaml"
echo "environments:" > $all_juju_envs
for unit in $UNITS; do

  # Derive new juju environment name
  unit_type=$(echo $unit | cut -d "/" -f 1)
  unit_num=$(echo $unit | cut -d "/" -f 2)
  case "$unit_type" in
    jenkins) new_env="osci-ma${unit_num}";;
    osci-slave) new_env="${juju_env_base}-sv${unit_num}";;
    *) echo "couldn't determine jenkins unit type for ${unit}"; exit 1;;
  esac

  f_tmp="out/environments_${new_env}.yaml"
  cat $env_templ | \
    sed -e "s/__TENANT__/$OS_TENANT_NAME/g" -e "s/__PASSWORD__/$OS_PASSWORD/g" \
      -e "s|__OS_AUTH_URL__|$OS_AUTH_URL|g" -e "s/__CONTROL__/$(uuid)/g" \
      -e "s/__SECRET__/$(pwgen 32 1)/g" -e "s|__APT_PROXY__|$apt_proxy|g" \
      -e "s/__ENVIRO__/$new_env/g" > $f_tmp

  cat $f_tmp | awk 'f;/environments:/{f=1}' >> $all_juju_envs

  echo "setting juju environment and novarc for ${unit} as: ${new_env}"
  juju scp $f_tmp ${unit}:"${U_HOME}/environments.yaml"
  juju scp ~/novarc ${unit}:"${U_HOME}/novarc"

  juju ssh $unit "sudo su - jenkins -c 'mkdir -p ${juju_dir}' &&\
    sudo mv ${U_HOME}/environments.yaml ${juju_dir} &&\
    sudo chown -R jenkins:jenkins ${juju_dir} &&\
    sudo chmod 600 ${juju_dir}/environments.yaml &&\
    sudo mv ${U_HOME}/novarc ${JENKINS_HOME} &&\
    sudo chown -R jenkins:jenkins ${JENKINS_HOME}/novarc &&\
    sudo chmod 600 ${JENKINS_HOME}/novarc"
done

for unit in $UNITS; do
  # Install Juju, Amulet, OpenStack CLI and misc tools on all units
  echo "installing packages on ${unit}"
  if [ ! -z "$(juju ssh $unit "lsb_release -c" | grep precise)" ]; then
    # Precise
    echo "Unit is precise"
    juju ssh $unit "sudo add-apt-repository ppa:juju/stable -y &&\
      sudo apt-get update -y &&\
      sudo apt-get install amulet juju-deployer juju-core iptraf htop nmap \
        nload multitail wget lynx python-novaclient python-quantumclient \
        python-keystoneclient -y"
  else
    # Not Precise
    echo "Unit is not precise"
    juju ssh $unit "sudo add-apt-repository ppa:juju/stable -y &&\
      sudo apt-get update -y &&\
      sudo apt-get install amulet juju-deployer juju-core iptraf htop nmap \
        nload multitail wget lynx python-novaclient python-neutronclient \
        python-keystoneclient python-glanceclient python-swiftclient -y"
  fi
done


