#!/bin/bash -e
echo $0

# Install jenkins cli jar on master and use it to install plugins

. $(dirname $0)/../../env-common

f_dst="${JENKINS_HOME}/jenkins-cli.jar"
f_tmp="${U_HOME}/jenkins-cli.jar"
plugins="deploy-files/plugins"

# Get jenkins master ip and url
master_ip=$(juju status --format=yaml ${MASTER} | grep public-address | awk '{ print $2 }')
master_url="http://${master_ip}:8080"
clijar_path="/jnlpJars/jenkins-cli.jar"

if [ -z $MASTER ]; then
    echo Jenkins master IP address not found.
    exit 1
else
    echo "Jenkins master: ${master_url}"
    sleep 1
fi

# Make sure jenkins web interface is ready for login before proceeding
j_state() {
    htm=$(curl -s ${master_url} || true)
    if [[ "$htm" =~ "Ubuntu OpenStack CI" ]]; then
        echo 'ready'
    else
        echo 'not ready'
    fi
}

ready=$(j_state)
tries=0
while [ "$ready" == 'not ready' ] && [ $tries -le 45 ]; do
    echo "Jenkins is ${ready} @ ${master_url} (attempt ${tries})"
    sleep 2
    ready=$(j_state)
    tries=$(( $tries + 1 ))
done

if [ "$(j_state)" == 'not ready' ]; then
    echo "No CLI or plugin install, jenkins master wasn't ready."
    exit 1
fi

# Sync jenkins plugin info with updatecenter
juju ssh ${MASTER} "export http_proxy=${HTTP_PROXY} &&\
    export https_proxy=${HTTPS_PROXY} &&\
    wget -O /tmp/jenkins-update-center.tmp http://updates.jenkins-ci.org/update-center.json &&\
    unset http_proxy && unset https_proxy &&\
    tail -n +2 /tmp/jenkins-update-center.tmp | head -n -1 > /tmp/jenkins-update-center.json &&\
    curl -X POST -d @/tmp/jenkins-update-center.json http://localhost:8080/updateCenter/byId/default/postBack --verbose"

# Remove CLI jar if it exists
juju ssh ${MASTER} " [ ! -f '${f_dst}' ] || sudo rm -fv ${f_dst}"
juju ssh ${MASTER} " [ ! -f '${f_tmp}' ] || sudo rm -fv ${f_tmp}"

# Install CLI jar from master (self)
#   ex: http://10.98.191.205:8080/jnlpJars/jenkins-cli.jar
juju ssh ${MASTER} "wget -O ${f_tmp} ${master_url}${clijar_path} &&\
    sudo chmod 666 ${f_tmp} &&\
    sudo chown jenkins:ubuntu ${f_tmp} &&\
    sudo cp -fvp ${f_tmp} ${f_dst}"

# Install plugins from plugin list file
if [ ! -f "$plugins" ]; then
    echo "Local plugins list file not found."
    exit 1
fi

for plugin in $(cat $plugins); do
    juju ssh ${MASTER} "java -jar jenkins-cli.jar -s \
        ${master_url} install-plugin ${plugin} \
        --username ubuntu --password ubuntu"
done

# Restart the jenkins master service
juju ssh ${MASTER} "sudo service jenkins restart &&\
    sudo service jenkins status"
