#!/bin/bash -e
echo $0

# Assign a floating IP to the juju-gui unit

. $(dirname $0)/../../env-common

ip_f_str="10.98."

function get_ip_f {
    local var=$(nova floating-ip-list | grep '\-  ' | awk '{ print $4 }' | head -n 1 |\
        egrep '^((25[0-5]|2[0-4][0-9]|[1]?[1-9][0-9]?).){3}(25[0-5]|2[0-4][0-9]|[1]?[1-9]?[0-9])$')
    echo $var
}

# Get UUID of jenkins instance
unit_uuid=$(juju status --format=yaml juju-gui | grep instance-id | awk '{ print $2 }' |\
    egrep '[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}')
if [ -z "$unit_uuid" ]; then
    echo "Couldn't get UUID for juju gui instance."
    exit 1
fi

# Check for existing floating IP on juju gui instance
if [ ! -z "$(nova list | grep .*${unit_uuid}.*${ip_f_str})" ]; then
    echo "Instance already has floating IP."
    nova list | grep $unit_uuid
    exit 0
fi

# Get a free floating IP if available, create one if not.
ip_f=$(get_ip_f)
if [ -z "$ip_f" ]; then
    echo "Asking for a new floating IP."
    nova floating-ip-create
    ip_f=$(get_ip_f)
    if [ -z "$ip_f" ]; then
        echo "Couldn't get floating IP."
        exit 1
    fi
fi

# Associate the floating IP
nova floating-ip-associate $unit_uuid $ip_f
echo "===================juju gui info ==================="
juju status --format=yaml juju-gui
nova list | grep $unit_uuid
echo "Juju GUI floating IP:  ${ip_f}"
