#!/usr/bin/env python
'''
Generates tarmac.conf based on branches defind in mappings.yaml
'''

import logging
import os
import yaml
from common import osci_utils

# Set default logging level
logging.basicConfig(level=logging.DEBUG)

TM_CONFIG_DIR = '/var/lib/jenkins/.config/tarmac'


def update_tarmac_conf(branches):
    '''Write tarmac.conf, generated from provided branches list
    '''
    context = {}
    context['log_file'] = 'tarmac.log'
    context['branches'] = branches

    source = 'tarmac.conf.tmpl'
    target = os.path.join(TM_CONFIG_DIR, 'tarmac.conf')
    templates_dir = 'populate'
    logging.info('Rendering tarmac file: {}'.format(target))
    osci_utils.render(source, target, context, templates_dir)


def main():
    '''You are here.  Go!
    '''
    conf_map = osci_utils.read_yaml(osci_utils.MAP_FILE)

    # Examples
    logging.debug(osci_utils.openstack_release('precise'))
    logging.debug(osci_utils.uca_openstack_releases('precise'))

    # Write a new tarmac.conf file, for future use.
    # Tarmac functionality here is alpha/conceptual (not really used yet)
    update_tarmac_conf(conf_map['trigger-branches'])

    print(yaml.dump(conf_map, default_flow_style=False))


if __name__ == '__main__':
    main()
