#!/bin/bash -ex
echo $0

# Make tarball of jobs dirs and config.xml from jenkins master, pull it to
# local home.  Tarball names are timestamped.  Useful for backing up job
# configs without workspaces, history, artifacts, etc.

MASTER=$1

if [[ -z "$MASTER" ]]; then
    set +x
    echo "The jenkins master IP address or resolvable hostname is required as the only parameter."
    exit 1
fi

loc_dir="${HOME}/tmp.jobs"
mkdir -p $loc_dir
tmp_file="$(mktemp)"


# Script to use in remote units
cat > "$tmp_file" << "EOF"
d_str=$(date +"%Y%m%d%H%M%S%N")
jobs_dir="/var/lib/jenkins/jobs"
jobs_bare="${jobs_dir}-${d_str}"
tarball="jobs-${d_str}.tgz"
u_home="/home/ubuntu"
u_own="ubuntu:ubuntu"

mkdir -p $jobs_bare

for f in ${jobs_dir}/* ; do
    if [ -d "$f" ]; then
        new_job_dir=${jobs_bare}/$(basename ${f})
        mkdir -p ${new_job_dir}
        cp -f ${f}/config.xml ${new_job_dir}
    fi
done

tar -cvzf ${tarball} -C ${jobs_bare} .
sudo cp -fv ${tarball} ${u_home}
sudo chown $u_own ${u_home}/${tarball}
echo "${u_home}/${tarball}"
EOF

sudo chmod 770 $tmp_file

f_dst="/home/ubuntu/bare-copy-jobs.sh"
f_src="$tmp_file"

# Copy script into master and execute
scp $f_src ubuntu@${MASTER}:${f_dst}
ssh ubuntu@${MASTER} "sudo /home/ubuntu/bare-copy-jobs.sh"
scp ubuntu@${MASTER}:jobs-*.tgz ${loc_dir}
ls -al ${loc_dir}
