#!/bin/bash -e
. ${OSCI_ROOT}/run/job-parts/osci_job_common.sh
f_fresh_clean_start
f_check_out_universal

# Required for layerci
f_tool_refresh_release_tools
f_tool_refresh_bot_control
f_layerci_use_built_asset_if_relevant
f_layerci_build_if_necessary

# Series to exercise
DEVEL_SERIES_EXERCISE="xenial bionic"
STABLE_SERIES_EXERCISE="xenial"

if [[ -z "$SERIES_EXERCISE" ]] && [[ "$GERRIT_BRANCH" != *stable* ]] && [[ "$GIT_BRANCH" != *stable* ]]; then
    # Master (dev)
    export SERIES_EXERCISE=$DEVEL_SERIES_EXERCISE
elif [[ -z "$SERIES_EXERCISE" ]] && [[ "$GERRIT_BRANCH" != "master" ]] && [[ "$GIT_BRANCH" != "master" ]]; then
    # Stable (released)
    export SERIES_EXERCISE=$STABLE_SERIES_EXERCISE
else
    echo " ! Unable to determine SERIES_EXERCISE based on GERRIT_BRANCH and/or GIT_BRANCH values"
    exit 1
fi

# Check for skipfile in central bot-control repo
SKIP_SINGLE="${UOSCI_BOT_CONTROL_ROOT}/config/charm-single/$BASE_NAME.skip"
if [[ -f "$SKIP_SINGLE" ]]; then
    echo " ! Skipping charm-single for $BASE_NAME per bot-control"
    cat $SKIP_SINGLE
    cp -fv $SKIP_SINGLE $WORKSPACE/charm-single.skip
    exit 0
fi

# Bootstrap Controller and add Model if necessary
f_juju_bootstrap

# Deploy
set -x
export DEPLOY_TMPDIR=$(mktemp -d)
for THIS_SERIES in $SERIES_EXERCISE; do
    APP_NAME="$BASE_NAME-${THIS_SERIES::1}"

    # Prep charm series dirs
    echo " + Copying ${BUILT_ASSET_DIR-$CO_DIR}/ --> $DEPLOY_TMPDIR/$THIS_SERIES/$BASE_NAME/"
    mkdir -p $DEPLOY_TMPDIR/$THIS_SERIES/$BASE_NAME
    cp -rfp ${BUILT_ASSET_DIR-$CO_DIR}/* $DEPLOY_TMPDIR/$THIS_SERIES/$BASE_NAME/

    # Use a series-named config yaml file if it exists, otherwise look for charmname.yaml
    YAML_BY_RELEASE="${UOSCI_BOT_CONTROL_ROOT}/config/charm-single/$BASE_NAME-$THIS_SERIES.yaml"
    YAML_BY_BASENAME="${UOSCI_BOT_CONTROL_ROOT}/config/charm-single/$BASE_NAME.yaml"

    if [[ -f "$YAML_BY_THIS_SERIES" ]]; then
        CHARM_SINGLE_YAML="$YAML_BY_RELEASE"
    elif [[ -f "$YAML_BY_BASENAME" ]]; then
        CHARM_SINGLE_YAML="$YAML_BY_BASENAME"
    else
        echo " . No charm-single config yaml to apply for $BASE_NAME"
        CHARM_SINGLE_YAML=""
    fi

    # Render charm app config if an override exists
    if [[ ! -z "$CHARM_SINGLE_YAML" ]]; then
        YAML_TMP_DIR="$(mktemp -d)"
        YAML_TMP=$YAML_TMP_DIR/$APP_NAME.yaml
        cp $CHARM_SINGLE_YAML $YAML_TMP
        echo " + Rendering file: $CHARM_SINGLE_YAML to $YAML_TMP"

        f_activate_botcontrol_tools_virtualenv
        ${UOSCI_BOT_CONTROL_ROOT}/tools/env-render -vy $YAML_TMP
        sed -e "s/^$BASE_NAME:/$APP_NAME:/" -i $YAML_TMP
        cp $YAML_TMP $WORKSPACE/$APP_NAME.yaml.txt

        echo " + Setting juju config on $APP_NAME from $YAML_tmp"
        cat $YAML_TMP

        cd $UOSCI_BOT_CONTROL_ROOT
        git reset --hard
        cd $WORKSPACE
        OPT_CONFIG_STRING="--config $YAML_TMP"
    fi

    juju deploy $DEPLOY_TMPDIR/$THIS_SERIES/$BASE_NAME $APP_NAME $OPT_CONFIG_STRING --series $THIS_SERIES
done
set +x

# Wait and Check
f_juju_wait
f_juju_stat
# XXX: REVISIT  f_juju_status_health_check

# Cleanup
rm -rf ${DEPLOY_TMPDIR:?}
rm -rf ${BUILT_ASSET_DIR-$CO_DIR:?}
f_line "End test charm single"

f_lolo_log_puller
f_set_build_descr
f_nice_finish
f_check_fail
