#!/bin/bash -e
# OpenStack Test Deployment
test="deploy"

# Source the common functions
. ${OSCI_ROOT}/run/job-parts/osci_job_common.sh

#f_fresh_clean_start
# NOTE: workspace not cleaned at this step, as the jenkins job may be copying
# artifacts to the workspace from another job (such as uploading a custom bundle).
# Workspace should have been cleaned as step 0 in the jenkins job.
f_refreshtools_jujuclean
f_env_no_pass
f_touch_try

# Handle merge-proposal trigger and substitute the proposed branch in the bundle file
#f_openstack_mergeprop_bundle_handler

# Handle custom deployer bundle file if present
f_openstack_custom_bundle_handler

# Go!
f_line "Deploy OpenStack"
f_openstack_deploy

# Float and announce guis
f_floaters
f_announce_gui_floats

# Confirm deployment, configure it, run tempest smoke
f_line "Confirm deployment"
juju_ok="$(${OSCI_ROOT}/run/job-parts/juju1_deploy_ok.sh ||:)"
echo $juju_ok
f_juju_status_health_check "-post-deploy"

if [[ "$juju_ok" == *DEPLOYED:* ]]; then
  echo " . OpenStack juju deployment succeeded."
  touch $WORKSPACE/fyi-${test:0:4}.deploy.ok

  f_line "Validate CLI auth and basic functionality"
  f_openstack_cli_basic_check

  f_line "Misc post-deploy configs and checks"
  f_openstack_tempstack_config

  f_line "Configure via o-c-t script"
  f_openstack_configure

  f_line "Create heat stack from git templates repo"
  f_openstack_heat_stack_create

  f_juju_stat "-pre-tempest"

  f_line "Create venv for tempest..."
  f_openstack_tempest_venv

  f_line "Run tempest smoke tests"
  f_openstack_run_tempest_smoke

  f_line "Pull tempest summary"
  f_openstack_tempest_summarize
else
  echo " ! Juju deployment failed."
  echo " ! Skipping tempest."
  touch $WORKSPACE/fyi.tempest.skipped
  touch $WORKSPACE/fyi.deploy.failed
fi

# XXX: f_collect_juju_logs

f_line "End of deployment test"
f_set_build_descr
#f_post_mp_comment
f_nice_finish
f_openstack_check_fail
