#!/bin/bash -e
# UOSCI:OSI build script
# See README.hacking before manually running this, or any other UOSCI build script.

# XXX: With slaves on Xenial, legacy openstack-installer packages don't exist.
echo " ! DEPRECATED: openstack-installer unavailable for Xenial"
exit 1


test="osi"

# (MMCC): turn off the logging filter that is currently squelching messages from
#         juju websocket API library
export UCI_NOFILTER=1
export OSI_TESTRUNNER_ID="d14a1e85-2bc3-4164-88ac-647910346e76"

# Define defaults for manual runs outside of a Jenkins environment
[[ -z "$JENKINS_HOME" ]] && export JENKINS_HOME="$HOME"
[[ -z "$WORKSPACE" ]] && export WORKSPACE="$(mktemp -d)"
[[ -z "$BUILD_NUMBER" ]] && export BUILD_NUMBER="manual"

[[ -z "$OSCI_REPO" ]] && export OSCI_REPO="lp:ubuntu-openstack-ci"
[[ -z "$OSCI_ROOT" ]] && export OSCI_ROOT="${HOME}/tools/ubuntu-openstack-ci"

[[ -z "$OPENSTACK_CHARM_TESTING_REPO" ]] && export OPENSTACK_CHARM_TESTING_REPO="lp:openstack-charm-testing"
[[ -z "$OPENSTACK_CHARM_TESTING_ROOT" ]] && export OPENSTACK_CHARM_TESTING_ROOT="${HOME}/tools/openstack-charm-testing"

# Avoid environment teardown if run outside of a Jenkins environment
[[ -z "$BUILD_URL" ]] && export NO_POST_DESTROY="true"

# OSI defaults when undefined
[[ -z "$OSI_CLOUD_INSTALL_DIR" ]] && export OSI_CLOUD_INSTALL_DIR="$JENKINS_HOME/.cloud-install"
[[ -z "$OSI_JUJU_HOME" ]] && export OSI_JUJU_HOME="$OSI_CLOUD_INSTALL_DIR/juju"
[[ -z "$OSI_MODE" ]] && export OSI_MODE="multi"

[[ -z "$UOSCI_JUJU_CONSTRAINTS" ]] && export UOSCI_JUJU_CONSTRAINTS="arch=amd64"
[[ -z "$UOSCI_MAAS_TAGS" ]] && export UOSCI_MAAS_TAGS="tags=uosci"

# Source the common functions
. ${OSCI_ROOT}/run/job-parts/osci_job_common.sh

f_fresh_clean_start
f_env_no_pass
f_touch_try
f_amulet_set_network_env_vars

# Go!
f_line "Deploy via OSI (openstack-installer mode: ${OSI_MODE})"
f_juju_get_pkg_info juju-pkg-info.txt
f_osi_deploy
f_juju_stat "-post-deploy"

# Confirm deployment, configure it, run tests
f_line "Confirm deployment"
export JUJU_HOME=$OSI_JUJU_HOME
juju_ok="$(${OSCI_ROOT}/run/job-parts/juju1_deploy_ok.sh ||:)"
echo $juju_ok
f_juju_status_health_check "-post-deploy"

if [[ "$juju_ok" == *DEPLOYED:* ]]; then
  # Generically, the juju deployment is believed to be sane.
  echo " . OSI Juju deployment succeeded."
  touch $WORKSPACE/fyi-${test:0:4}.deploy.ok

  # Basic functional validation per mode
  case "$OSI_MODE" in
    "multi"|"single")
      f_line "Validate OpenStack API/CLI auth and basic functionality"
      f_novarc_overcloud
      f_osi_basic_deploy_validation
      f_osi_basic_deploy_cli_check
      ;;
    # "autopilot")
    # Not yet implemented.
  esac

  f_line "OSI integrated tests"
  f_osi_built_in_ci_tests

else
  # Generically, the juju deployment is not sane.
  echo " ! OSI Juju deployment failed."
  touch $WORKSPACE/fyi.deploy.failed
fi

# Collect OSI dir, juju unit logs, and other artifacts
f_osi_collect
f_collect_juju_logs

f_line "OSI uninstall (destroy)"
f_osi_uninstall
unset JUJU_HOME

f_line "End of deployment test"
f_set_build_descr
f_nice_finish

f_openstack_check_fail
