#!/bin/bash -e

function f_juju1_get_model_name() {
# Determine Juju 1 model name to run with
  juju_enviro_file="${HOME}/.juju/environments.yaml"
  if [[ "$MOJO_SPEC" != *metal* ]]; then
    # Not bare metal
    case "$JUJU_SOURCE" in
      $JUJU_STABLE)
        echo " . Juju stable"
        JENV_NAME="$(grep '^default:' ${juju_enviro_file} | head -n1 | cut -f2 -d ':' | xargs)"
        ;;
      $JUJU_PROPOSED)
        echo " . Juju proposed"
        JENV_NAME="$(grep '.jprop:$' ${juju_enviro_file} | head -n1 | cut -f1 -d ':' | xargs)"
        ;;
      $JUJU_DEVEL)
        echo " . Juju devel"
        JENV_NAME="$(grep '.jdev:$' ${juju_enviro_file} | head -n1 | cut -f1 -d ':' | xargs)"
        ;;
      *)
        echo " ! Unknown JUJU_SOURCE value while determining jenv name."
        echo "JUJU_SOURCE: $JUJU_SOURCE"
        exit 1
        ;;
    esac
  else
    # Bare metal
    echo " . Handling juju environment switcher for bare metal..."
    case "$JUJU_SOURCE" in
      $JUJU_STABLE)
        echo " . Juju stable"
        JENV_NAME="$(grep "maas-${UBUNTU_RELEASE}:$" ${juju_enviro_file} | head -n1 | cut -f1 -d ':' | xargs)"
        ;;
      $JUJU_PROPOSED)
        echo " . Juju proposed"
        JENV_NAME="$(grep .jprop:$ ${juju_enviro_file} | grep "maas-${UBUNTU_RELEASE}" | head -n1 | cut -f1 -d ':' | xargs)"
        ;;
      $JUJU_DEVEL)
        echo " . Juju devel"
        JENV_NAME="$(grep .jdev:$ ${juju_enviro_file} | grep "maas-${UBUNTU_RELEASE}" | head -n1 | cut -f1 -d ':' | xargs)"
        ;;
      *)
        echo " ! Unknown JUJU_SOURCE value while determining jenv name."
        echo "JUJU_SOURCE: $JUJU_SOURCE"
        exit 1
        ;;
    esac
  fi

  # Validate as non-empty
  if [[ -z "$JENV_NAME" ]]; then
    echo " ! Could not determine an appropriate JENV_NAME."
        echo "JUJU_SOURCE: $JUJU_SOURCE"
    exit 1
  fi
  export JENV_NAME
  echo " . JUJU_SOURCE: $JUJU_SOURCE"
  echo " . JENV_NAME: $JENV_NAME"
}


function XXX_f_collect_juju1_logs() {
# Collect juju stat and logs
  echo "Collecting juju status and unit logs..."

  # Check again before collecting logs
  #f_juju_status_health_check "-collect" ||:

  f_juju_stat "-collect" ||:

  . $JENKINS_HOME/novarc
  ${OSCI_ROOT}/tools/nova_instances_summarize.py ||:
  ${OSCI_ROOT}/tools/juju_pull_logs.py ||:
}


function f_juju1_stat() {
  juju stat --format=yaml &> $WORKSPACE/juju-stat-yaml${1}.txt ||:
  juju stat --format=tabular &> $WORKSPACE/juju-stat-tabular${1}.txt ||:
}


function f_juju1_bootstrap() {
  f_line "Bootstrapping juju with client: $(juju version), model: $(juju switch)"
  echo " . Bootstrap parameters: $1 $2 $3 $4 $5"
  juju bootstrap $1 $2 $3 $4 $5 2>&1 | tee $WORKSPACE/juju-bootstrap.txt
  if [[ "${PIPESTATUS[0]}" != "0" ]]; then
    echo " ! Bootstrap failed."
    touch $WORKSPACE/fyi-${test:0:4}.${test}-bootstrap.failed
  fi
}
