#!/bin/bash -e
#
#  Common functions for UOSCI jobs, specific to mojo functionality.

function f_mojo_broom() {
  if [[ -d "/srv/mojo/mojo-openstack-specs/" ]]; then
    echo " - Purging /srv/mojo/mojo-openstack-specs"
    rm -rf /srv/mojo/mojo-openstack-specs/*
    echo " - Purging $MOJO_ROOT"
    rm -rf ${MOJO_ROOT:?}
  fi
}


function f_mojo_new_project() {
# Add mojo project.
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping mojo project-new, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.mojo-project-new.skipped
  else
    set -x
    mojo-project-new --series ${UBUNTU_RELEASE} \
        --container containerless ${MOJO_PROJ} --mojo-root ${MOJO_ROOT} 2>&1 | tee $WORKSPACE/mojo-project-new.txt
    # Error trap
    if [[ "${PIPESTATUS[0]}" != "0" ]]; then
      echo " ! Failed to create new mojo project."
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-project-new.failed
      exit 1
    fi
    set +x
  fi
}


function f_mojo_new_workspace() {
# Add mojo workspace.
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping mojo workspace-new, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.mojo-workspace-new.skipped
  else
    set -x
    f_activate_clients
    mojo --mojo-root ${MOJO_ROOT} workspace-new --project ${MOJO_PROJ} --series ${UBUNTU_RELEASE} \
        --stage ${MOJO_SPEC}/${OPENSTACK_RELEASE} ${MOJO_OPENSTACK_SPECS_REPO} ${MOJO_WKSP} \
        2>&1 | tee $WORKSPACE/mojo-workspace-new.txt

    # Error trap
    if [[ "${PIPESTATUS[0]}" != "0" ]]; then
      echo " ! Failed to create new mojo workspace."
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-workspace-new.failed
      exit 1
    fi
    set +x
  fi
}


function f_mojo_run() {
# Run mojo, run!
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping mojo run, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.mojo-run.skipped
  else
    f_openstack_set_network_env_vars
    set -x
    f_activate_clients
    mojo --mojo-root ${MOJO_ROOT} run --project ${MOJO_PROJ} --series ${UBUNTU_RELEASE} \
        --stage ${MOJO_SPEC}/${OPENSTACK_RELEASE} "${MOJO_OPENSTACK_SPECS_REPO};revno=${MOJO_OPENSTACK_SPECS_BRANCH}" ${MOJO_WKSP} \
        2>&1 | tee $WORKSPACE/mojo-run.txt

    # Error trap
    if [[ "${PIPESTATUS[0]}" != "0" ]]; then
      echo " ! Mojo run manifest failed."
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-run.failed
    fi
    set +x
  fi
}


function f_mojo_handle_env_vars() {
# Validate and process mojo runner environment variables.
  # Basic confirmation of non-null values.
  options="MOJO_OPENSTACK_SPECS_REPO MOJO_OPENSTACK_SPECS_BRANCH MOJO_SPEC UBUNTU_RELEASE OPENSTACK_RELEASE MOJO_SERIES"
  for option in $options; do
    if [[ -z "${!option}" ]]; then
      echo " ! Failing on null option: ${option}"
      touch $WORKSPACE/fyi-${test:0:4}.${test}-mojo-env-vars.failed
    else
      echo "${option} ok: ${!option}"
    fi
  done

  # Fatal if error.  Aborts job build.
  f_set_build_descr
  f_check_fail
}
