#!/bin/bash -e
#
#  Common functions for UOSCI jobs, specific to OpenStack actions.


function XXXf_openstack_bundle_constraint_mod() {
# Bump some constraints to minimize resource footprint on undercloud.
#  ex.
#  echo "Modifying bundle constraints (4G:3072M)."
#  $OSCI_ROOT/run/tools/find_replace.py -yd -i "$BUNDLE_FILE" -o "$BUNDLE_FILE" -f "mem=4G" -r "mem=3072M" || touch $WORKSPACE/fyi-${test:0:4}.bundle-constraint-mod.failed
echo " . FYI no bundle mem constraint modifications"
}


function XXXf_openstack_mergeprop_bundle_handler() {
# Handle merge-proposal trigger and substitute the proposed branch in the bundle file
  if [[ -n "$MP_TRIGGER" ]] && [[ -n "$MP_SRC_BR" ]] && [[ -n "$MP_TGT_BR" ]] && [[ -n "$DISPLAY_NAME" ]]; then
    echo "Triggered by merge proposal: ${MP_TRIGGER}"
    echo "Substituting proposed branch in deployer bundle..."
    echo '' > $WORKSPACE/custom-other.yaml || true
    $OSCI_ROOT/run/tools/find_replace.py -yd -i "$OCT_CODIR/$CHARM_SET" -o "$WORKSPACE/custom-other.yaml" -f "$MP_TGT_BR" -r "$MP_SRC_BR" || touch $WORKSPACE/fyi-${test:0:4}.mp-branch-replace.failed
    export CHARM_SET="custom-other.yaml"
  fi
}


function XXXf_openstack_custom_bundle_handler() {
# Handle custom deployer bundle file if present
  if [[ "$CHARM_SET" == "custom-other.yaml" ]] && [[ -f custom-other.yaml ]]; then
    echo "Using custom-other deployer bundle yaml file..."
    export BUNDLE_FILE=$WORKSPACE/$CHARM_SET
    touch $WORKSPACE/fyi-${test:0:4}.custom.bundle
    f_openstack_bundle_constraint_mod
  else
    export BUNDLE_FILE=$OCT_CODIR/$CHARM_SET
    f_openstack_bundle_constraint_mod
    cp $OCT_CODIR/$CHARM_SET $WORKSPACE/${CHARM_SET##*/}.txt
  fi
}


function f_openstack_uos_env_var_normalize() {
# Ensure that both representations of the Ubuntu Release x OpenStack Release
# environment variables are set.
  if [[ -z "$UBUNTU_RELEASE" ]] && [[ -z "$OPENSTACK_RELEASE" ]] && [[ -n "$U_OS" ]]; then
    echo " . Using U_OS to determine UBUNTU_RELEASE and OPENSTACK_RELEASE."
    export UBUNTU_RELEASE=$(echo $U_OS | cut -f 1 -d "-")
    export MOJO_SERIES=$UBUNTU_RELEASE
    export OPENSTACK_RELEASE=$(echo $U_OS | cut -f 2 -d "-")

  elif [[ -n "$UBUNTU_RELEASE" ]] && [[ -n "$OPENSTACK_RELEASE" ]] && [[ -z "$U_OS" ]]; then
    echo " . Using UBUNTU_RELEASE and OPENSTACK_RELEASE to determine U_OS."
    export U_OS="${UBUNTU_RELEASE}-${OPENSTACK_RELEASE}"
    export MOJO_SERIES=$UBUNTU_RELEASE

  elif [[ -n "$UBUNTU_RELEASE" ]] && [[ -n "$OPENSTACK_RELEASE" ]] && [[ -n "$U_OS" ]]; then
    echo " . UBUNTU_RELEASE, OPENSTACK_RELEASE and U_OS are all set."
    export MOJO_SERIES=$UBUNTU_RELEASE
  fi
}


function XXXf_openstack_deploy() {
# Deploy the stack
  echo "Deploying OpenStack..."
  INST_SOURCE=""
  [[ "$INSTALLATION_SOURCE" != "default" ]] && INST_SOURCE="-${INSTALLATION_SOURCE}"
  (cd $OCT_CODIR &&\
  juju-deployer --timeout 2700 --bootstrap -c ${BUNDLE_FILE} -d ${UBUNTU_RELEASE}-${OPENSTACK_RELEASE}${INST_SOURCE}) \
    2>&1 | tee $WORKSPACE/juju-deployer.txt
  f_juju_wait_on_workload
}


function XXXf_openstack_tempstack_config() {
# Configure the deployed tempstack

  # Shrink flavors for smaller resource footprint in testing
  f_flavor_shrink 2>&1 | tee $WORKSPACE/flavor-shrink.txt || true
  if [[ "${PIPESTATUS[0]}" != "0" ]]; then
    echo " ! Flavor shrink failed."
    touch $WORKSPACE/fyi-${test:0:4}.${test}-flavor-shrink.failed
  fi

  echo "Calling tempstack configure to tweak network, add test keys..."
  ${OSCI_ROOT}/run/job-parts/part_tempstack_configure.sh 2>&1 | tee $WORKSPACE/tempstack-configure.txt || true

  if [[ -n "$(grep 'END RSA PRIVATE KEY' $WORKSPACE/testkey.pem.$BUILD_NUMBER || true)" ]]; then
    echo " . Tempstack configure ok."
    touch $WORKSPACE/fyi-${test:0:4}.tempstack-configure.ok
  else
    echo " ! Tempstack configure failed."
    touch $WORKSPACE/fyi-${test:0:4}.tempstack-configure.failed
  fi
}


function f_amulet_squash_00setup() {
# Guard against ppa additions and deb package installations as are
# customarily attempted in tests/00-setup and/or tests/setup/00-setup.
# That is dangerous in CI automation as we need to control the juju
# and related tools versions on the slaves.  Just squash them here.
  f_line "Squashing 00-setup files if they exist"
  pwd
  if [[ -d ./tests ]]; then
    AMULET_SETUP_FILES="$(find ./tests -type f -executable -name 00-setup -print ||:)"
  fi
  if [[ ! -z "$AMULET_SETUP_FILES" ]]; then
    for f in $AMULET_SETUP_FILES; do
      echo " - Setting $f as non-executable (-x)"
      chmod -x $f
      stat $f
    done
  else
    echo " . No executable amulet 00-setup file(s) found (OK)."
  fi
}


function f_amulet_naked_test_run() {
# LEGACY!  Run a single named amulet test. Must already be bootstrapped.
# This should only be used when amulet smoke tests are not defined in
# the charm's tox.ini.  Once all charms use tox + bundletester for
# amulet and amulet smoke, this can be deprecated.
  if [[ -z "${BUILT_ASSET_DIR-$CO_DIR}" ]]; then
    echo " ! Missing a required env var: BUILT_ASSET_DIR or CO_DIR"
    exit 1
  fi
  if [[ -z "$AMULET_TEST_NAME" ]]; then
    echo " ! Missing the required AMULET_TEST_NAME env var."
    exit 1
  fi
  cd ${BUILT_ASSET_DIR-$CO_DIR}
  # Call the amulet test file directly
  $AMULET_TEST_NAME |& tee $WORKSPACE/amulet-smoke.txt || true
  if [[ "${PIPESTATUS[0]}" != "0" ]]; then
    echo " ! Amulet smoke test failed: $AMULET_TEST_NAME."
    touch $WORKSPACE/fyi-amulet-smoke.failed
  fi
}


function f_amulet_smoke_select_tests_fallback() {
# LEGACY!  Only use this if/when a tox + bundletester amulet smoke
# target is not defined or found.  This is intended only as a fallback
# with automatic test selection.  OpenStack charms should all eventually
# have tox-defined tests.

  # Need to update this each cycle
  export PREFER_CURRENT_LTS="trusty"
  export BLACKLIST_CURRENT_OS_DEV="mitaka"

  if [[ -z "${BUILT_ASSET_DIR-$CO_DIR}" ]]; then
    echo " ! Missing a required env var: BUILT_ASSET_DIR or CO_DIR"
    exit 1
  fi
  cd ${BUILT_ASSET_DIR-$CO_DIR}

  export AMULET_TESTS_ALL="$(find ./tests -maxdepth 1 -type f -executable -print | sort)"

  # Select Preferred Test: latest trusty test combo which is enabled and executable
  # Exclude *git* (deploy-from-source) amulet test definitions.
  export AMULET_TEST_NAME="$(echo "$AMULET_TESTS_ALL" | grep $PREFER_CURRENT_LTS | grep -v git | grep -v $BLACKLIST_CURRENT_OS_DEV | tail -n 1)"

  # Select Alternate Test: first in lexical order which is enabled and executable
  # Exclude *git* (deploy-from-source) amulet test definitions.
  if [[ -z "$AMULET_TEST_NAME" ]]; then
    export AMULET_TEST_NAME="$(echo "$AMULET_TESTS_ALL" | grep -v git | grep -v $BLACKLIST_CURRENT_OS_DEV | head -n 1)"
  fi

  # Still no test found based on preference or blacklist, just run with one.
  # Exclude *git* (deploy-from-source) amulet test definitions.
  if [[ -z "$AMULET_TEST_NAME" ]]; then
    export AMULET_TEST_NAME="$(echo "$AMULET_TESTS_ALL" | grep -v git | head -n 1)"
  fi

  # Fail and bail if none found.
  if [[ -z "$AMULET_TEST_NAME" ]]; then
    echo " ! NO TEST FOUND - Unable to determine which amulet test to run from ${BUILT_ASSET_DIR-$CO_DIR}/tests"
    ls -al ${BUILT_ASSET_DIR-$CO_DIR}/tests
    exit 1
  fi

  echo " . Available amulet tests:"
  echo "$AMULET_TESTS_ALL"
  echo " . Automatically selected test:  $AMULET_TEST_NAME"
}


function f_amulet_set_odl_location() {
    f_line $FUNCNAME
    # Set ODL tarball location if not already set.
    [[ -z "$AMULET_ODL_LOCATION" ]] && export AMULET_ODL_LOCATION='http://10.245.161.162/swift/v1/opendaylight/distribution-karaf-0.2.4-Helium-SR4.tar.gz'
    [[ -z "$AMULET_ODL_HE_LOCATION" ]] && export AMULET_ODL_HE_LOCATION='http://10.245.161.162/swift/v1/opendaylight/distribution-karaf-0.2.4-Helium-SR4.tar.gz'
    [[ -z "$AMULET_ODL_LI_LOCATION" ]] && export AMULET_ODL_LI_LOCATION='http://10.245.161.162/swift/v1/opendaylight/distribution-karaf-0.3.3-Lithium-SR3.tar.gz'
    [[ -z "$AMULET_ODL_BE_LOCATION" ]] && export AMULET_ODL_BE_LOCATION='http://10.245.161.162/swift/v1/opendaylight/distribution-karaf-0.4.0-Beryllium.tar.gz'
    echo "    AMULET_ODL_LOCATION: $AMULET_ODL_LOCATION"
    echo "    AMULET_ODL_HE_LOCATION: $AMULET_ODL_HE_LOCATION"
    echo "    AMULET_ODL_LI_LOCATION: $AMULET_ODL_LI_LOCATION"
    echo "    AMULET_ODL_BE_LOCATION: $AMULET_ODL_BE_LOCATION"
}


function f_amulet_set_ldap_location() {
    f_line $FUNCNAME
    # Setup LDAP test fixture for keystone-ldap testing
    [[ -z "$AMULET_LDAP_SERVER" ]] && export AMULET_LDAP_SERVER="ldap://10.245.162.249/"
    [[ -z "$AMULET_LDAP_USER" ]] && export AMULET_LDAP_USER="cn=admin,dc=test,dc=com"
    [[ -z "$AMULET_LDAP_PASSWORD" ]] && export AMULET_LDAP_PASSWORD="crapper"
    [[ -z "$AMULET_LDAP_SUFFIX" ]] && export AMULET_LDAP_SUFFIX="dc=test,dc=com"
    echo "    AMULET_LDAP_SERVER: $AMULET_LDAP_SERVER"
    echo "    AMULET_LDAP_USER: $AMULET_LDAP_USER"
    echo "    AMULET_LDAP_PASSWORD: $AMULET_LDAP_PASSWORD"
    echo "    AMULET_LDAP_SUFFIX: $AMULET_LDAP_SUFFIX"
}


function f_openstack_set_network_env_vars() {
    f_line $FUNCNAME
    f_activate_clients
    f_subnet_id
    export NAME_SERVER="$(awk '/^nameserver /{ print $2 }' /etc/resolv.conf | head -n 1 | xargs)"
    export NET_ID="$NETWORK_ID"
    export CIDR_EXT="$NETWORK_CIDR"
    # export GATEWAY="$(/sbin/route -n | awk '/^0.0.0.0 /{ print $2 }')"
    export GATEWAY="$(ipcalc $CIDR_EXT | awk '/HostMin:/{ print $2 }')"
    CIDR_END="$(ipcalc $CIDR_EXT | awk '/^HostMax: /{ print $2 }')"
    FIP_END="$(echo $CIDR_END | sed 's/254/239/g')"
    # OSCI subnet dhcp pools end at the highest .199, so the
    # floating IP and VIP pools are safe in the last .200-254 of the network.
    FIP_START=$(echo $CIDR_END | sed "s/254/200/g")
    export FIP_RANGE="${FIP_START}:${FIP_END}"
    export AMULET_OS_VIP00=$(echo $CIDR_END | sed "s/254/240/g")
    export AMULET_OS_VIP01=$(echo $CIDR_END | sed "s/254/241/g")
    export AMULET_OS_VIP02=$(echo $CIDR_END | sed "s/254/242/g")
    export AMULET_OS_VIP03=$(echo $CIDR_END | sed "s/254/243/g")
    export AMULET_OS_VIP04=$(echo $CIDR_END | sed "s/254/244/g")
    export AMULET_OS_VIP05=$(echo $CIDR_END | sed "s/254/245/g")
    export AMULET_OS_VIP06=$(echo $CIDR_END | sed "s/254/246/g")
    export AMULET_OS_VIP07=$(echo $CIDR_END | sed "s/254/247/g")
    export AMULET_OS_VIP08=$(echo $CIDR_END | sed "s/254/248/g")
    export AMULET_OS_VIP09=$(echo $CIDR_END | sed "s/254/249/g")
    export AMULET_OS_VIP10=$(echo $CIDR_END | sed "s/254/250/g")
    export AMULET_OS_VIP11=$(echo $CIDR_END | sed "s/254/251/g")
    export AMULET_OS_VIP12=$(echo $CIDR_END | sed "s/254/252/g")
    export AMULET_OS_VIP13=$(echo $CIDR_END | sed "s/254/253/g")
    export AMULET_OS_VIP=$AMULET_OS_VIP00
    export VIP_RANGE="${AMULET_OS_VIP00}:${AMULET_OS_VIP13}"

    export OS_VIP00=$AMULET_OS_VIP00
    export OS_VIP01=$AMULET_OS_VIP01
    export OS_VIP02=$AMULET_OS_VIP02
    export OS_VIP03=$AMULET_OS_VIP03
    export OS_VIP04=$AMULET_OS_VIP04
    export OS_VIP05=$AMULET_OS_VIP05
    export OS_VIP06=$AMULET_OS_VIP06
    export OS_VIP07=$AMULET_OS_VIP07
    export OS_VIP08=$AMULET_OS_VIP08
    export OS_VIP09=$AMULET_OS_VIP09
    export OS_VIP10=$AMULET_OS_VIP10
    export OS_VIP11=$AMULET_OS_VIP11
    export OS_VIP12=$AMULET_OS_VIP12
    export OS_VIP13=$AMULET_OS_VIP13

    echo "  + Setting network env vars:"
    echo "    NET_ID: $NET_ID"
    echo "    GATEWAY: $GATEWAY"
    echo "    NAME_SERVER: $NAME_SERVER"
    echo "    CIDR_EXT: $CIDR_EXT"
    echo "    FIP_RANGE: $FIP_RANGE"
    echo "    VIP_RANGE: $VIP_RANGE"
    echo "    AMULET_OS_VIP: $AMULET_OS_VIP"
    echo "    AMULET_OS_VIP00: $AMULET_OS_VIP00"
    echo "    AMULET_OS_VIP01: $AMULET_OS_VIP01"
    echo "    AMULET_OS_VIP02: $AMULET_OS_VIP02"
    echo "    AMULET_OS_VIP03: $AMULET_OS_VIP03"
    echo "    AMULET_OS_VIP04: $AMULET_OS_VIP04"
    echo "    AMULET_OS_VIP05: $AMULET_OS_VIP05"
    echo "    AMULET_OS_VIP06: $AMULET_OS_VIP06"
    echo "    AMULET_OS_VIP07: $AMULET_OS_VIP07"
    echo "    AMULET_OS_VIP08: $AMULET_OS_VIP08"
    echo "    AMULET_OS_VIP09: $AMULET_OS_VIP09"
    echo "    AMULET_OS_VIP10: $AMULET_OS_VIP10"
    echo "    AMULET_OS_VIP11: $AMULET_OS_VIP11"
    echo "    AMULET_OS_VIP12: $AMULET_OS_VIP12"
    echo "    AMULET_OS_VIP13: $AMULET_OS_VIP13"
    echo "    VIP_RANGE: $VIP_RANGE"
    f_amulet_set_odl_location
    f_amulet_to_mojo_env_vars
    f_amulet_set_ldap_location
}


function f_amulet_set_network_env_vars() {
    f_line $FUNCNAME
    f_openstack_set_network_env_vars
}


function f_amulet_to_mojo_env_vars() {
    export MOJO_NAME_SERVER=$NAME_SERVER
    export MOJO_NET_ID=$NET_ID
    export MOJO_SUBNET_ID=$SUBNET_ID
    export MOJO_CIDR_EXT=$CIDR_EXT
    export MOJO_GATEWAY=$GATEWAY
    export MOJO_FIP_RANGE=$FIP_RANGE
    export MOJO_OS_VIP00=$AMULET_OS_VIP00
    export MOJO_OS_VIP01=$AMULET_OS_VIP01
    export MOJO_OS_VIP02=$AMULET_OS_VIP02
    export MOJO_OS_VIP03=$AMULET_OS_VIP03
    export MOJO_OS_VIP04=$AMULET_OS_VIP04
    export MOJO_OS_VIP05=$AMULET_OS_VIP05
    export MOJO_OS_VIP06=$AMULET_OS_VIP06
    export MOJO_OS_VIP07=$AMULET_OS_VIP07
    export MOJO_OS_VIP08=$AMULET_OS_VIP08
    export MOJO_OS_VIP09=$AMULET_OS_VIP09
    export MOJO_OS_VIP10=$AMULET_OS_VIP10
    export MOJO_OS_VIP11=$AMULET_OS_VIP11
    export MOJO_OS_VIP12=$AMULET_OS_VIP12
    export MOJO_OS_VIP13=$AMULET_OS_VIP13
    export MOJO_OS_VIP=$AMULET_OS_VIP
    export MOJO_VIP_RANGE=$VIP_RANGE
    echo "  + Setting mojo network env vars:"
    echo "    MOJO_NAME_SERVER: $MOJO_NAME_SERVER"
    echo "    MOJO_NET_ID: $MOJO_NET_ID"
    echo "    MOJO_SUBNET_ID: $MOJO_SUBNET_ID"
    echo "    MOJO_CIDR_EXT: $MOJO_CIDR_EXT"
    echo "    MOJO_GATEWAY: $MOJO_GATEWAY"
    echo "    MOJO_FIP_RANGE: $MOJO_FIP_RANGE"
    echo "    MOJO_OS_VIP00: $MOJO_OS_VIP00"
    echo "    MOJO_OS_VIP01: $MOJO_OS_VIP01"
    echo "    MOJO_OS_VIP02: $MOJO_OS_VIP02"
    echo "    MOJO_OS_VIP03: $MOJO_OS_VIP03"
    echo "    MOJO_OS_VIP04: $MOJO_OS_VIP04"
    echo "    MOJO_OS_VIP05: $MOJO_OS_VIP05"
    echo "    MOJO_OS_VIP06: $MOJO_OS_VIP06"
    echo "    MOJO_OS_VIP07: $MOJO_OS_VIP07"
    echo "    MOJO_OS_VIP08: $MOJO_OS_VIP08"
    echo "    MOJO_OS_VIP09: $MOJO_OS_VIP09"
    echo "    MOJO_OS_VIP10: $MOJO_OS_VIP10"
    echo "    MOJO_OS_VIP11: $MOJO_OS_VIP11"
    echo "    MOJO_OS_VIP12: $MOJO_OS_VIP12"
    echo "    MOJO_OS_VIP13: $MOJO_OS_VIP13"
    echo "    MOJO_OS_VIP: $MOJO_OS_VIP"
    echo "    MOJO_VIP_RANGE: $MOJO_VIP_RANGE"
}


function XXXf_openstack_configure() {
# Run the openstack-charm-testing ./configure script
  echo "Configuring..."
  f_openstack_set_network_env_vars

  cd $OCT_CODIR
  ./configure $OCT_CONFIG_PROFILE 2>&1 | tee $WORKSPACE/configure.txt || true
  cp -v $OCT_CODIR/tempest.conf $WORKSPACE/tempest.conf.txt || true

  if [[ -f $WORKSPACE/tempest.conf.txt ]]; then
    echo " . Configure succeeded."
    touch $WORKSPACE/fyi-${test:0:4}.configure.ok
  else
    echo " ! Configure failed."
    touch $WORKSPACE/fyi-${test:0:4}.configure.failed
  fi

  # Heat requires an action for Kilo and later to enable authorization
  if [[ "$OPENSTACK_RELEASE" != *icehouse* ]]; then
    echo " . Running domain-setup action on heat/0..."
    juju action do --format=json heat/0 domain-setup
  fi
}


function XXXf_openstack_heat_stack_create() {
# add a basic heat HOT template stack for tempest orchestration tests
# experimental, force pass for now
  if [[ "$CHARM_SET" != "bundles/lxd/default.yaml" ]] && [[ "$CHARM_SET" != "bundles/lxd/next.yaml" ]]; then
    export HEAT_IMAGE_NAME="cirros"
  else
    export HEAT_IMAGE_NAME="trusty-root.tar.xz"
    echo " . Using alternate image name for LXD heat stack: ${HEAT_IMAGE_NAME}"
  fi
  heat stack-create heat_basic -f $OCT_CODIR/templates/heat/heat-basic.yaml \
    --parameters "admin_pass=Ubuntu;key_name=testkey;image=${HEAT_IMAGE_NAME};network=private" || true
  heat stack-list || true
}


function XXXf_openstack_tempest_venv() {
  cd $OCT_CODIR/tempest
  virtualenv .venv
  .venv/bin/pip install -r requirements.txt
  .venv/bin/pip install python-ceilometerclient python-cinderclient python-glanceclient python-heatclient \
      python-keystoneclient python-neutronclient python-novaclient python-swiftclient python-openstackclient
}


function XXXf_openstack_run_tempest_smoke() {
# Run tempest if nothing has failed so far, and if enabled.
  if [ "$TEMPEST_SMOKE" != "true" ]; then
    echo " . Skipping tempest due to disabled boolean parameter (set TEMPEST_SMOKE to true)."
    touch $WORKSPACE/fyi-${test:0:4}.tempest.skipped
    return 0
  fi
  if [[ -n "$(ls $WORKSPACE -1 | egrep '.failed|.bad')" ]]; then
    echo " ! Skipping tempest, one or more preceding steps are failed or bad."
    touch $WORKSPACE/fyi-${test:0:4}.tempest.skipped
  else
    # Kick off tempest
    (cd $OCT_CODIR/tempest && ./run_tempest.sh -V --smoke) 2>&1 |\
      tee $WORKSPACE/tempest-allresults.txt
    if [[ -n "$(grep 'failures=' $WORKSPACE/tempest-allresults)" ]]; then
      echo " ! One or more tempest smoke tests failed."
      touch $WORKSPACE/fyi-${test:0:4}.tempest.bad
    elif [[ -z "$(grep 'failures=' $WORKSPACE/tempest-allresults)" ]] &&\
         [[ -n "$(grep 'tempest.scenario.test' $WORKSPACE/tempest-allresults)" ]] ; then
      echo " . All tempest smoke tests passed!"
      touch $WORKSPACE/fyi-${test:0:4}.tempest.ok
    else
      echo " ! Unknown tempest result condition."
    fi
  fi
}


function XXXf_openstack_tempest_summarize() {
  if [[ -f $WORKSPACE/tempest-allresults ]]; then
    egrep 'FAIL|^Ran|====|SKIP' $WORKSPACE/tempest-allresults > $WORKSPACE/tempest-summary || true
  fi
}


function XXXf_openstack_cli_basic_check() {
# Perform basic command line checks against the cloud
  echo "Confirming basic CLI functionality and authentication..."
  . $OCT_CODIR/novarc
  tmp_cmds="$(mktemp)"
  cat > "$tmp_cmds" << "--EOF1"
  ceilometer resource-list
  glance image-list
  heat stack-list
  keystone ec2-credentials-list
  keystone endpoint-list
  keystone role-list
  keystone service-list
  keystone tenant-list
  keystone token-get
  keystone user-list
  keystone user-role-list
  neutron net-list
  neutron router-list
  neutron subnet-list
  nova flavor-list
  nova floating-ip-list
  nova floating-ip-pool-list
  nova keypair-list
  nova host-list
  nova hypervisor-list
  nova image-list
  nova network-list
  nova secgroup-list
  nova service-list
  swift list
--EOF1

  if [[ "$CHARM_SET" != "bundles/lxd/default.yaml" ]] && [[ "$CHARM_SET" != "bundles/lxd/next.yaml" ]]; then
  # The lxd bundle does not currently deploy cinder.
  cat >> "$tmp_cmds" << "--EOF2"
  cinder list
  cinder list-extensions
  cinder snapshot-list
  cinder transfer-list
  cinder type-list
--EOF2
  else
    echo " . Skipping cinder cli/api checks for lxd bundle."
  fi

  while read cmd; do
    echo -n "${cmd}: "
    $cmd &> /dev/null && echo 'ok' ${PIPESTATUS[0]} || { echo 'cli-fail' ${PIPESTATUS[0]}; touch $WORKSPACE/fyi-${test:0:4}.cli.failed; }
  done < $tmp_cmds
  rm -fv $tmp_cmds
}


function f_openstack_check_fail() {
# Check for failure touchfiles and fail if found
# Exclude '.bad' statuses such as tempest fail
# ie. pass the deploy even as tempest fails
  lso="$(ls $WORKSPACE -1)"
  if [[ "$lso" == *.failed* ]] || \
     [[ "$lso" == *.missing* ]]; then
    echo " ! Exiting 1."
    exit 1
  fi
}


function f_novarc_undercloud() {
  echo " . Sourcing undercloud novarc."
  stat -t ~/novarc
  . ~/novarc
}


function f_novarc_overcloud() {
  echo " . Sourcing overcloud novarc."
  stat -t $OCT_CODIR/novarc
  . $OCT_CODIR/novarc
}


function f_novarc_artifactcloud() {
  echo " . Sourcing artifactcloud novarc."
  . ~/novarc-artifactcloud
}


function XXXf_flavor_shrink() {
# Shrink flavors for smaller/faster testing
  echo " + Shrinking flavors."
  nova flavor-delete m1.small
  nova flavor-delete m1.medium
  nova flavor-delete m1.large
  nova flavor-delete m1.xlarge
  nova flavor-create --ephemeral 0 --is-public True m1.small 2 512 8 1
  nova flavor-create --ephemeral 0 --is-public True m1.medium 3 1024 12 2
  nova flavor-create --ephemeral 0 --is-public True m1.large 4 1536 14 3
  nova flavor-create --ephemeral 0 --is-public True m1.xlarge 5 2048 16 4
  nova flavor-list
}


function XXXf_deployer_quickcheck() {
# Deploy a nothing-special bundle just to confirm deployer functionality and environment health.
  echo "Deploying a quick check bundle..."
  [[ -z "$SERIES" ]] && export SERIES="trusty"
  [[ -z "$BUNDLE_FILE" ]] && export BUNDLE_FILE="${OCT_CODIR}/bundles/other/ubuntu3.yaml"
  (cd $OCT_CODIR &&\
  juju-deployer --timeout 1800 --bootstrap -c ${BUNDLE_FILE} -d ${SERIES}) \
    2>&1 | tee $WORKSPACE/juju-deployer.txt
  f_juju_wait
}


function XXXf_get_floating_ip() {
# Return the first available floating IP.  Assumes at least 1 exists.
  nova floating-ip-list | grep '\-  ' | awk '{ print $2 }' | head -n 1
}


function XXXf_floaters() {
# Assign floating IP addresses to units listed in the FLOATERS
# environment variable.  Non-fatal if units do not exist.
# Also non-fatal if association fails.
  [[ -z "$FLOATERS" ]] && export FLOATERS="juju-gui/0 openstack-dashboard/0"
  f_novarc_undercloud
  jstat_all=$(mktemp)
  jstat=$(mktemp)
  juju stat --format=yaml > $jstat_all

  for unit in $FLOATERS; do
    if [[ -z "$(grep $unit $jstat_all)" ]]; then
      echo " ! Unit not found to float: ${unit}"
    else
      juju stat $unit --format=yaml > $jstat
      iid=$(grep instance-id $jstat | awk '{ print $2 }')
      fip=$(f_get_floating_ip)
      ip_f=$(f_get_floating_ip)
      echo " + Associating floating IP ${fip} to instance ${iid} for unit ${unit}."
      nova floating-ip-associate $iid $fip || true
    fi
  done
  rm -fv $jstat_all
  rm -fv $jstat
}


function XXXf_announce_gui_floats() {
# Display juju gui and openstack dashboard URLs if they exist.
# Also announce ubuntu/0 floating IP for debug purposes, if exists.
  f_line "GUI info, if available"
  jgui_fip=$(juju stat --format=yaml juju-gui/0 | grep public-address | cut -f 2 -d ":" | xargs || true)
  dash_fip=$(juju stat --format=yaml openstack-dashboard/0 | grep public-address | cut -f 2 -d ":" | xargs || true)
  ubnt_fip=$(juju stat --format=yaml ubuntu/0 | grep public-address | cut -f 2 -d ":" | xargs || true)
  [[ -n "$jgui_fip" ]] && echo "Juju GUI URL:  https://${jgui_fip}" || true
  [[ -n "$dash_fip" ]] && echo "OpenStack Dashboard URL:  http://${dash_fip}/horizon" || true
  [[ -n "$ubnt_fip" ]] && echo "Ubuntu Floating IP:  ${ubnt_fip}" || true
}
