#!/bin/bash -e
#
#  Common functions for UOSCI jobs, specific to refreshing tool repos/branches.

: ${EXECUTOR_NUMBER:="z"}
: ${BASE_CODIR:="${HOME}/tools/$EXECUTOR_NUMBER"}

: ${CTI_REPO:="https://github.com/openstack-charmers/charm-test-infra"}
: ${CTI_REPO_BRANCH:="master"}
: ${CTI_CODIR:="${BASE_CODIR}/charm-test-infra"}

: ${OCT_REPO:="lp:openstack-charm-testing"}
# : ${OCT_REPO_BRANCH:="NotApplicable"}
: ${OCT_CODIR:="${BASE_CODIR}/openstack-charm-testing"}

export EXECUTOR_NUMBER
export BASE_CODIR
export CTI_REPO
export CTI_REPO_BRANCH
export CTI_CODIR

export OCT_REPO
# export OCT_REPO_BRANCH
export OCT_CODIR


function f_tool_refresh_cti() {
  f_line $FUNCNAME
  if [[ -n $CTI_CODIR ]] && [[ -d $CTI_CODIR ]]; then
    rm -rf ${CTI_CODIR:?}
  fi
  git clone -q --depth=1 $CTI_REPO $CTI_CODIR -b $CTI_REPO_BRANCH
  git -C $CTI_CODIR branch -av
  git -C $CTI_CODIR remote -v
}


function f_vcs_configure() {
  f_line $FUNCNAME
  bzr whoami "uoscibot <uosci-testing-bot@ubuntu.com>"
  bzr launchpad-login uosci-testing-bot
  git config --global user.email "uosci-testing-bot@ubuntu.com"
  git config --global user.name "uoscibot"
  git config --global gitreview.username "uosci-testing-bot"
}


function f_tool_refresh_oct() {
  f_line $FUNCNAME
  if [[ -d $OCT_CODIR ]]; then
    rm -rf ${OCT_CODIR:?}
  fi
  bzr co --lightweight $OCT_REPO $OCT_CODIR
  bzr info $OCT_CODIR
  bzr revno $OCT_CODIR
}


function f_tool_refresh_juju_wait() {
# keep juju_wait fresh
  f_line $FUNCNAME
  : ${EXECUTOR_NUMBER:="z"}
  [[ -z "$JUJU_WAIT_ROOT" ]] && export JUJU_WAIT_ROOT="${HOME}/tools/$EXECUTOR_NUMBER/juju-wait"
  [[ -z "$JUJU_WAIT_REPO" ]] && export JUJU_WAIT_REPO="https://git.launchpad.net/juju-wait"
  [[ -z "$JUJU_WAIT_BRANCH" ]] && export JUJU_WAIT_BRANCH="master"

  # HOLD for: https://bugs.launchpad.net/juju-wait/+bug/1641163
  # [[ -z "$JUJU_WAIT_REPO" ]] && export JUJU_WAIT_REPO="https://git.launchpad.net/~1chb1n/juju-wait"
  # [[ -z "$JUJU_WAIT_BRANCH" ]] && export JUJU_WAIT_BRANCH="revert-for-lp1641163"

  if [[ -d $JUJU_WAIT_ROOT ]]; then
    rm -rf ${JUJU_WAIT_ROOT:?}
  fi

  git clone -q --depth=1 $JUJU_WAIT_REPO $JUJU_WAIT_ROOT -b $JUJU_WAIT_BRANCH
  git -C $JUJU_WAIT_ROOT branch -av
  git -C $JUJU_WAIT_ROOT remote -v
}


function f_tool_refresh_bot_control() {
# Git the bot-control repo
  f_line $FUNCNAME
  : ${EXECUTOR_NUMBER:="z"}
  [[ -z "$UOSCI_BOT_CONTROL_REPO" ]] && export UOSCI_BOT_CONTROL_REPO="https://github.com/openstack-charmers/bot-control.git"
  [[ -z "$UOSCI_BOT_CONTROL_ROOT" ]] && export UOSCI_BOT_CONTROL_ROOT="${HOME}/tools/$EXECUTOR_NUMBER/bot-control"

  [[ -z "$UOSCI_BOT_CONTROL_BRANCH" ]] && export UOSCI_BOT_CONTROL_BRANCH="master"

  if [[ -d $UOSCI_BOT_CONTROL_ROOT ]]; then
    rm -rf ${UOSCI_BOT_CONTROL_ROOT:?}
  fi

  git clone -q --depth=1 $UOSCI_BOT_CONTROL_REPO $UOSCI_BOT_CONTROL_ROOT -b $UOSCI_BOT_CONTROL_BRANCH
  git -C $UOSCI_BOT_CONTROL_ROOT branch -av
  git -C $UOSCI_BOT_CONTROL_ROOT remote -v
}


function f_tool_refresh_release_tools() {
# Git the release-tools repo
  f_line $FUNCNAME
  : ${EXECUTOR_NUMBER:="z"}
  [[ -z "$UOSCI_RELEASE_TOOLS_REPO" ]] && export UOSCI_RELEASE_TOOLS_REPO="https://github.com/openstack-charmers/release-tools"
  [[ -z "$UOSCI_RELEASE_TOOLS_ROOT" ]] && export UOSCI_RELEASE_TOOLS_ROOT="${HOME}/tools/$EXECUTOR_NUMBER/release-tools"
  [[ -z "$UOSCI_RELEASE_TOOLS_BRANCH" ]] && export UOSCI_RELEASE_TOOLS_BRANCH="master"

  if [[ -d $UOSCI_RELEASE_TOOLS_ROOT ]]; then
    rm -rf ${UOSCI_RELEASE_TOOLS_ROOT:?}
  fi

  git clone -q --depth=1 $UOSCI_RELEASE_TOOLS_REPO $UOSCI_RELEASE_TOOLS_ROOT -b $UOSCI_RELEASE_TOOLS_BRANCH
  git -C $UOSCI_RELEASE_TOOLS_ROOT branch -av
  git -C $UOSCI_RELEASE_TOOLS_ROOT remote -v
}
